Contact To A Template Project — collective.templates documentation

# Contact To A Template Project

There are two mail forms available to get in contact with a template project and send feedback to its main contact respective owner.

## Mail Form On The Project Page

There is a mail form linked from the project resources tool bar on the right side of a template project page. This contact form set already the project name of the project, from which page it is called. The user need only to fill in his name, mail address and message to the project (owner/contact) into the form. The form is secured by a captcha.

## Mail Form On The Start Page Of The Template Center

Another mail form is linked directly from the sidebar of the Template Center. This form differs from the one on the project pages, because it has not already a default entry for the project name. Thus the user of this form has to know the name of the template project and write it into the form field.

It is on the disposition of the template project owner / contact if he get back to the sender of the mail. The mail address of the project owner / contact is not public visible and will not be submitted to the sender of the contact form.